// e.g. for sport:
// const [dark, main, bright, pastel, faded] = colors.blue

var colors = {
  reds: ["#AB0613", //news-dark
  "#C70000", //news-main
  "#FF5943", //news-bright
  "#FFBAC8", //news-pastel
  "#FFF4F2"],
  oranges: ["#AB0613", //opinion-dark
  "#E05E00", //opinion-main
  "#FF7F0F", //opinion-bright
  "#F9B376", //opinion-pastel
  "#FEF9F5"],
  blues: ["#005689", //sport-dark
  "#0084C6", //sport-main
  "#00B2FF", //sport-bright
  "#90DCFF", //sport-pastel
  "#F1F8FC", //sport-faded
  "#041F4A", //brand-dark
  "#052962", //brand-main
  "#007ABC", //brand-bright
  "#506991", //brand-pastel
  "#C1D8FC"],
  browns: ["#6B5840", //culture-dark
  "#A1845C", //culture-main
  "#EACCA0", //culture-bright
  "#E7D4B9", //culture-pastel
  "#FBF6EF"],
  pinks: ["#7D0068", //lifestyle-dark
  "#BB3B80", //lifestyle-main
  "#FFABDB", //lifestyle-bright
  "#FEC8D3", //lifestyle-pastel
  "#FEEEF7"],
  yellows: ["#F3C100", //highlight-dark
  "#FFE500"],
  greens: ["#185E36", "#22874D", //success-main
  "#65A897", //labs-dark
  "#69D1CA"],
  grays: ["#121212", //neutral-7
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF", //neutral-100
  "#3F464A", //special-report
  "#1A1A1A"]
};
var space = [0, 4, 8, 12, 20, 24, 36, 48, 96];
var size = [24, 36, 44];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [375, 480, 660];
var transitions = [".2s cubic-bezier(.64, .57, .67, 1.53)", ".3s ease-in-out", ".65s ease-in-out"];

var transitions$1 = {
  "short": transitions[0],
  medium: transitions[1],
  "long": transitions[2]
};

var breakpoints$1 = {
  mobileMedium: tweakpoints[0],
  mobileLandscape: tweakpoints[1],
  phablet: tweakpoints[2],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var brand = {
  dark: colors.blues[5],
  main: colors.blues[6],
  bright: colors.blues[7],
  pastel: colors.blues[8],
  faded: colors.blues[9]
};
var brandYellow = {
  dark: colors.yellows[0],
  main: colors.yellows[1] // TOO: remove in v0.9.0, prefer brandYellow

};
var yellow = {
  dark: colors.yellows[0],
  main: colors.yellows[1]
};
var neutral = {
  7: colors.grays[0],
  20: colors.grays[1],
  46: colors.grays[2],
  60: colors.grays[3],
  86: colors.grays[4],
  93: colors.grays[5],
  97: colors.grays[6],
  100: colors.grays[7],
  specialReport: colors.grays[8],
  // TODO: remove in v0.9.0, prefer background.dark.primary
  darkMode: colors.grays[9]
};
var error = {
  main: colors.reds[1],
  bright: colors.reds[2]
};
var success = {
  main: colors.greens[1]
};
var news = {
  dark: colors.reds[0],
  main: colors.reds[1],
  bright: colors.reds[2],
  pastel: colors.reds[3],
  faded: colors.reds[4]
};
var opinion = {
  dark: colors.oranges[0],
  main: colors.oranges[1],
  bright: colors.oranges[2],
  pastel: colors.oranges[3],
  faded: colors.oranges[4]
};
var sport = {
  dark: colors.blues[0],
  main: colors.blues[1],
  bright: colors.blues[2],
  pastel: colors.blues[3],
  faded: colors.blues[4]
};
var culture = {
  dark: colors.browns[0],
  main: colors.browns[1],
  bright: colors.browns[2],
  pastel: colors.browns[3],
  faded: colors.browns[4]
};
var lifestyle = {
  dark: colors.pinks[0],
  main: colors.pinks[1],
  bright: colors.pinks[2],
  pastel: colors.pinks[3],
  faded: colors.pinks[4]
};
var labs = {
  dark: colors.greens[2],
  main: colors.greens[3] // functional colours

};
var text = {
  primary: neutral[7],
  secondary: neutral[46],
  error: error.main,
  ctaPrimary: neutral[100],
  ctaSecondary: brand.main,
  mono: {
    primary: neutral[100],
    secondary: neutral[60],
    ctaPrimary: neutral[7],
    ctaSecondary: neutral[100]
  },
  brand: {
    primary: neutral[100],
    secondary: neutral[60],
    error: error.bright,
    ctaPrimary: brand.main,
    ctaSecondary: neutral[100]
  },
  brandYellow: {
    primary: neutral[7],
    secondary: neutral[60],
    ctaPrimary: neutral[100],
    ctaSecondary: neutral[7]
  },
  readerRevenue: {
    primary: neutral[100],
    secondary: neutral[60],
    ctaPrimary: brand.main,
    ctaSecondary: brandYellow.main
  },
  readerRevenueYellow: {
    primary: neutral[7],
    secondary: neutral[60],
    ctaPrimary: neutral[100],
    ctaSecondary: neutral[7]
  }
};
var background = {
  primary: neutral[100],
  ctaPrimary: brand.main,
  ctaPrimaryHover: "#234B8A",
  ctaSecondary: brand.faded,
  ctaSecondaryHover: "#96B0D9",
  radioChecked: brand.main,
  mono: {
    primary: neutral[7],
    ctaPrimary: neutral[100],
    ctaPrimaryHover: neutral[93],
    ctaSecondary: neutral[46],
    ctaSecondaryHover: "#5C5C5C"
  },
  brand: {
    primary: brand.main,
    ctaPrimary: neutral[100],
    ctaPrimaryHover: neutral[93],
    ctaSecondary: brand.pastel,
    ctaSecondaryHover: "#234B8A",
    radioChecked: neutral[100]
  },
  brandYellow: {
    primary: brandYellow.main,
    ctaPrimary: neutral[7],
    ctaPrimaryHover: neutral[20],
    ctaSecondary: brandYellow.dark,
    ctaSecondaryHover: "#F2AE00"
  },
  readerRevenue: {
    primary: brand.main,
    ctaPrimary: brandYellow.main,
    ctaPrimaryHover: brandYellow.dark,
    ctaSecondary: brand.main,
    ctaSecondaryHover: brand.dark
  },
  readerRevenueYellow: {
    primary: brandYellow.main,
    ctaPrimary: neutral[7],
    ctaPrimaryHover: neutral[20],
    ctaSecondary: brandYellow.main,
    ctaSecondaryHover: brandYellow.dark
  }
};
var border = {
  error: error.main,
  radio: neutral[60],
  radioHover: brand.main,
  brand: {
    error: error.bright,
    radio: neutral[100],
    radioHover: brand.faded
  },
  readerRevenue: {
    ctaSecondary: brandYellow.main
  },
  readerRevenueYellow: {
    ctaSecondary: neutral[7]
  }
};
var palette = {
  brand: brand,
  brandYellow: brandYellow,
  yellow: yellow,
  neutral: neutral,
  error: error,
  success: success,
  news: news,
  opinion: opinion,
  sport: sport,
  culture: culture,
  lifestyle: lifestyle,
  labs: labs,
  text: text,
  background: background,
  border: border
};

var size$1 = {
  small: size[0],
  medium: size[1],
  large: size[2]
};

var space$1 = {
  1: space[1],
  2: space[2],
  3: space[3],
  5: space[4],
  6: space[5],
  9: space[6],
  12: space[7],
  24: space[8]
};

export { breakpoints$1 as breakpoints, palette, size$1 as size, space$1 as space, transitions$1 as transitions };
